@@ -1,13 +1,13 @@
 # Copyrights 2008-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 use warnings;
 use strict;
 
 package XML::Compile::Cache;
 use vars '$VERSION';
-$VERSION = '0.90';
+$VERSION = '0.91';
 
 use base 'XML::Compile::Schema';
 
@@ -239,7 +239,7 @@ sub mergeCompileOptions(@)
             @p{keys %t} = values %t;   # overwrite old def if exists
         }
         elsif($opt eq 'hooks' || $opt eq 'hook')
-        {   my $hooks = @{$self->_cleanup_hooks($val)};
+        {   my $hooks = $self->_cleanup_hooks($val);
             unshift @{$opts{hooks}}, ref $hooks eq 'ARRAY' ? @$hooks : $hooks
                 if $hooks;
         }
@@ -381,7 +381,7 @@ sub printIndex(@)
           = $self->{XCC_writers}{$type} ? 'W'
           : $self->{XCC_dwopts}{$type}  ? 'w' : ' ';
     }
-    print $fh @output;
+    $fh->print(@output);
 }
 
 #---------------
@@ -391,6 +391,7 @@ sub _convertAnyElementReader(@)
 {   my ($self, $type, $nodes, $path, $read, $args) = @_;
 
     my $reader  = try { $self->reader($type) };
+#warn "TRY CONVERT $type; $@" if $@;
     !$@ && $reader or return ($type => $nodes);
 
     my @nodes   = ref $nodes eq 'ARRAY' ? @$nodes : $nodes;
